@@ -71,7 +71,7 @@ class const_iterator;
 class const_preorder_iterator;
 class const_postorder_iterator;
 class symbol;
-class symbolhasher;
+struct symbolhasher;
 using symbolset = std::unordered_set<symbol,symbolhasher>;
 using expairvec = std::vector<std::pair<ex,ex>>;
 
@@ -87,9 +87,9 @@ class ex {
 	template<class T> friend inline bool is_a(const ex &);
 	template<class T> friend inline bool is_exactly_a(const ex &);
 	
-	friend struct print_order;
-	friend struct print_order_mul;
-	friend struct print_order_pair;
+	friend class print_order;
+	friend class print_order_mul;
+	friend class print_order_pair;
 	// default constructor, copy constructor and assignment operator
 public:
 	ex() throw();
@@ -201,6 +201,7 @@ public:
 	// differentiation and series expansion
 	ex diff(const symbol & s, unsigned nth = 1) const;
 	ex series(const ex & r, int order, unsigned options = 0) const;
+        void useries(flint_series_t& fp, int order) const { return bp->useries(fp, order); }
 
 	// rational functions
 	ex normal(int level = 0, bool noexpand_combined=false,
@@ -212,6 +213,7 @@ public:
 #ifdef PYNAC_HAVE_LIBGIAC
         const giac::polynome to_polynome(ex_int_map& map, exvector& revmap) const;
 #endif
+        const CanonicalForm to_canonical(ex_int_map& map, exvector& revmap) const;
 	ex numer() const;
 	ex denom() const;
 	ex numer_denom() const;
